@@ -327,12 +327,13 @@ def tsqr(data, compute_svd=False, _max_vchunk_size=None):
             # cumulative sums (start, end)
             name_q2cs = "cumsum" + token + "-q2"
             dsk_q2_cumsum = {(name_q2cs, 0): [0, (name_q2bs, 0)]}
-            dsk_q2_cumsum.update(
-                {
-                    (name_q2cs, i): (_cumsum_part, (name_q2cs, i - 1), (name_q2bs, i))
-                    for i in range(1, numblocks[0])
-                }
-            )
+
+            for i in range(1, numblocks[0]):
+                dsk_q2_cumsum[(name_q2cs, i)] = (
+                    _cumsum_part,
+                    (name_q2cs, i - 1),
+                    (name_q2bs, i),
+                )
 
             # obtain slices on q from in-core compute (e.g.: (slice(10, 20), slice(0, 5)))
             name_blockslice = "slice" + token + "-q"
