@@ -274,9 +274,11 @@ class Aggregation(object):
         self.__name__ = name
 
 
-def _groupby_aggregate(df, aggfunc=None, levels=None, dropna=None, **kwargs):
+def _groupby_aggregate(
+    df, aggfunc=None, levels=None, dropna=None, sort=False, **kwargs
+):
     dropna = {"dropna": dropna} if dropna is not None else {}
-    return aggfunc(df.groupby(level=levels, sort=False, **dropna), **kwargs)
+    return aggfunc(df.groupby(level=levels, sort=sort, **dropna), **kwargs)
 
 
 def _apply_chunk(df, *index, dropna=None, **kwargs):
@@ -313,12 +315,12 @@ def _var_chunk(df, *index):
     return concat([x, x2, n], axis=1)
 
 
-def _var_combine(g, levels):
-    return g.groupby(level=levels, sort=False).sum()
+def _var_combine(g, levels, sort=False):
+    return g.groupby(level=levels, sort=sort).sum()
 
 
-def _var_agg(g, levels, ddof):
-    g = g.groupby(level=levels, sort=False).sum()
+def _var_agg(g, levels, ddof, sort=False):
+    g = g.groupby(level=levels, sort=sort).sum()
     nc = len(g.columns)
     x = g[g.columns[: nc // 3]]
     # chunks columns are tuples (value, name), so we just keep the value part
@@ -429,7 +431,7 @@ def _cov_chunk(df, *index):
     return (x, mul, n, col_mapping)
 
 
-def _cov_agg(_t, levels, ddof, std=False):
+def _cov_agg(_t, levels, ddof, std=False, sort=False):
     sums = []
     muls = []
     counts = []
@@ -444,8 +446,8 @@ def _cov_agg(_t, levels, ddof, std=False):
         counts.append(n)
         col_mapping = col_mapping
 
-    total_sums = concat(sums).groupby(level=levels, sort=False).sum()
-    total_muls = concat(muls).groupby(level=levels, sort=False).sum()
+    total_sums = concat(sums).groupby(level=levels, sort=sort).sum()
+    total_muls = concat(muls).groupby(level=levels, sort=sort).sum()
     total_counts = concat(counts).groupby(level=levels).sum()
     result = (
         concat([total_sums, total_muls, total_counts], axis=1)
@@ -523,8 +525,8 @@ def _drop_duplicates_rename(df):
     return df.drop_duplicates().rename_axis(names, copy=False)
 
 
-def _nunique_df_combine(df, levels):
-    result = df.groupby(level=levels, sort=False).apply(_drop_duplicates_rename)
+def _nunique_df_combine(df, levels, sort=False):
+    result = df.groupby(level=levels, sort=sort).apply(_drop_duplicates_rename)
 
     if isinstance(levels, list):
         result.index = pd.MultiIndex.from_arrays(
@@ -536,8 +538,8 @@ def _nunique_df_combine(df, levels):
     return result
 
 
-def _nunique_df_aggregate(df, levels, name):
-    return df.groupby(level=levels, sort=False)[name].nunique()
+def _nunique_df_aggregate(df, levels, name, sort=False):
+    return df.groupby(level=levels, sort=sort)[name].nunique()
 
 
 def _nunique_series_chunk(df, *index, **_ignored_):
@@ -698,8 +700,10 @@ def _build_agg_args(spec):
         impls = _build_agg_args_single(result_column, func, input_column)
 
         # overwrite existing result-columns, generate intermediates only once
-        chunks.update((spec[0], spec) for spec in impls["chunk_funcs"])
-        aggs.update((spec[0], spec) for spec in impls["aggregate_funcs"])
+        for spec in impls["chunk_funcs"]:
+            chunks[spec[0]] = spec
+        for spec in impls["aggregate_funcs"]:
+            aggs[spec[0]] = spec
 
         finalizers.append(impls["finalizer"])
 
@@ -897,9 +901,9 @@ def _compute_sum_of_squares(grouped, column):
     return base.apply(lambda x: (x ** 2).sum())
 
 
-def _agg_finalize(df, aggregate_funcs, finalize_funcs, level):
+def _agg_finalize(df, aggregate_funcs, finalize_funcs, level, sort=False):
     # finish the final aggregation level
-    df = _groupby_apply_funcs(df, funcs=aggregate_funcs, level=level)
+    df = _groupby_apply_funcs(df, funcs=aggregate_funcs, level=level, sort=sort)
 
     # and finalize the result
     result = collections.OrderedDict()
@@ -987,15 +991,21 @@ class _GroupBy(object):
         Passed to pandas.DataFrame.groupby()
     dropna: bool
         Whether to drop null values from groupby index
+    sort: bool, defult None
+        Passed along to aggregation methods. If allowed,
+        the output aggregation will have sorted keys.
     """
 
-    def __init__(self, df, by=None, slice=None, group_keys=True, dropna=None):
+    def __init__(
+        self, df, by=None, slice=None, group_keys=True, dropna=None, sort=None
+    ):
 
         assert isinstance(df, (DataFrame, Series))
         self.group_keys = group_keys
         self.obj = df
         # grouping key passed via groupby method
         self.index = _normalize_index(df, by)
+        self.sort = sort
 
         if isinstance(self.index, list):
             do_index_partition_align = all(
@@ -1093,6 +1103,7 @@ class _GroupBy(object):
             ),
             split_out=split_out,
             split_out_setup=split_out_on_index,
+            sort=self.sort,
         )
 
     def _cum_agg(self, token, chunk, aggregate, initial):
@@ -1347,6 +1358,7 @@ class _GroupBy(object):
             split_every=split_every,
             split_out=split_out,
             split_out_setup=split_out_on_index,
+            sort=self.sort,
         )
 
         if isinstance(self.obj, Series):
@@ -1405,6 +1417,7 @@ class _GroupBy(object):
             split_every=split_every,
             split_out=split_out,
             split_out_setup=split_out_on_index,
+            sort=self.sort,
         )
 
         if isinstance(self.obj, Series):
@@ -1520,6 +1533,7 @@ class _GroupBy(object):
             split_every=split_every,
             split_out=split_out,
             split_out_setup=split_out_on_index,
+            sort=self.sort,
         )
 
     @insert_meta_param_description(pad=12)
@@ -1705,9 +1719,13 @@ class DataFrameGroupBy(_GroupBy):
 
     def __getitem__(self, key):
         if isinstance(key, list):
-            g = DataFrameGroupBy(self.obj, by=self.index, slice=key, **self.dropna)
+            g = DataFrameGroupBy(
+                self.obj, by=self.index, slice=key, sort=self.sort, **self.dropna
+            )
         else:
-            g = SeriesGroupBy(self.obj, by=self.index, slice=key, **self.dropna)
+            g = SeriesGroupBy(
+                self.obj, by=self.index, slice=key, sort=self.sort, **self.dropna
+            )
 
         # error is raised from pandas
         g._meta = g._meta[key]
@@ -1789,6 +1807,7 @@ class SeriesGroupBy(_GroupBy):
             split_every=split_every,
             split_out=split_out,
             split_out_setup=split_out_on_index,
+            sort=self.sort,
         )
 
     @derived_from(pd.core.groupby.SeriesGroupBy)
