@@ -11,7 +11,7 @@ import tlz as toolz
 import numpy as np
 import pandas as pd
 
-from .core import DataFrame, Series, _Frame, _concat, map_partitions
+from .core import DataFrame, Series, _Frame, _concat, map_partitions, new_dd_object
 
 from .. import base, config
 from ..base import tokenize, compute, compute_as_if_collection
@@ -508,91 +508,98 @@ def rearrange_by_column_tasks(
 
     token = tokenize(df, column, max_branch)
 
-    start = {
-        ("shuffle-join-" + token, 0, inp): (df._name, i)
-        if i < df.npartitions
-        else df._meta
-        for i, inp in enumerate(inputs)
-    }
+    shuffle_join_name = "shuffle-join-" + token
 
-    for stage in range(1, stages + 1):
-        group = {  # Convert partition into dict of dataframe pieces
-            ("shuffle-group-" + token, stage, inp): (
+    shuffle_group_name = "shuffle-group-" + token
+    shuffle_split_name = "shuffle-split-" + token
+    shuffle_token = "shuffle-" + token
+
+    start = {}
+    end = {}
+
+    for idx, inp in enumerate(inputs):
+        group = {}
+        split = {}
+        join = {}
+        start[(shuffle_join_name, 0, inp)] = (
+            (df._name, idx) if idx < df.npartitions else df._meta
+        )
+
+        for stage in range(1, stages + 1):
+            # Convert partition into dict of dataframe pieces
+            group[(shuffle_group_name, stage, inp)] = (
                 shuffle_group,
-                ("shuffle-join-" + token, stage - 1, inp),
+                (shuffle_join_name, stage - 1, inp),
                 column,
                 stage - 1,
                 k,
                 n,
                 ignore_index,
             )
-            for inp in inputs
-        }
 
-        split = {  # Get out each individual dataframe piece from the dicts
-            ("shuffle-split-" + token, stage, i, inp): (
-                getitem,
-                ("shuffle-group-" + token, stage, inp),
-                i,
-            )
-            for i in range(k)
-            for inp in inputs
-        }
+            _concat_list = []
+            for i in range(k):
+                # Get out each individual dataframe piece from the dicts
+                split[(shuffle_split_name, stage, i, inp)] = (
+                    getitem,
+                    (shuffle_group_name, stage, inp),
+                    i,
+                )
 
-        join = {  # concatenate those pieces together, with their friends
-            ("shuffle-join-" + token, stage, inp): (
-                _concat,
-                [
+                _concat_list.append(
                     (
-                        "shuffle-split-" + token,
+                        shuffle_split_name,
                         stage,
                         inp[stage - 1],
-                        insert(inp, stage - 1, j),
+                        insert(inp, stage - 1, i),
                     )
-                    for j in range(k)
-                ],
+                )
+
+            # concatenate those pieces together, with their friends
+            join[(shuffle_join_name, stage, inp)] = (
+                _concat,
+                _concat_list,
                 ignore_index,
             )
-            for inp in inputs
-        }
+
         groups.append(group)
         splits.append(split)
         joins.append(join)
 
-    end = {
-        ("shuffle-" + token, i): ("shuffle-join-" + token, stages, inp)
-        for i, inp in enumerate(inputs)
-    }
+        end[(shuffle_token, idx)] = (shuffle_join_name, stages, inp)
 
-    dsk = toolz.merge(start, end, *(groups + splits + joins))
-    graph = HighLevelGraph.from_collections("shuffle-" + token, dsk, dependencies=[df])
-    df2 = DataFrame(graph, "shuffle-" + token, df, df.divisions)
+    groups.extend(splits)
+    groups.extend(joins)
+
+    dsk = toolz.merge(start, end, *(groups))
+    graph = HighLevelGraph.from_collections(shuffle_token, dsk, dependencies=[df])
+
+    df2 = new_dd_object(graph, shuffle_token, df._meta, df.divisions)
 
     if npartitions is not None and npartitions != df.npartitions:
-        parts = [i % df.npartitions for i in range(npartitions)]
         token = tokenize(df2, npartitions)
 
+        repartition_group_token = "repartition-group-" + token
+
         dsk = {
-            ("repartition-group-" + token, i): (
-                shuffle_group_2,
-                k,
-                column,
-                ignore_index,
-            )
+            (repartition_group_token, i): (shuffle_group_2, k, column, ignore_index,)
             for i, k in enumerate(df2.__dask_keys__())
         }
+
+        repartition_get_name = "repartition-get-" + token
+
         for p in range(npartitions):
-            dsk[("repartition-get-" + token, p)] = (
+            dsk[(repartition_get_name, p)] = (
                 shuffle_group_get,
-                ("repartition-group-" + token, parts[p]),
+                (repartition_group_token, p % df.npartitions),
                 p,
             )
 
         graph2 = HighLevelGraph.from_collections(
-            "repartition-get-" + token, dsk, dependencies=[df2]
+            repartition_get_name, dsk, dependencies=[df2]
         )
-        df3 = DataFrame(
-            graph2, "repartition-get-" + token, df2, [None] * (npartitions + 1)
+        df3 = new_dd_object(
+            graph2, repartition_get_name, df2._meta, [None] * (npartitions + 1)
         )
     else:
         df3 = df2
